@@ -12,8 +12,8 @@ use warnings::register;
 use SelfLoader;
 
 use vars qw($VERSION $DATE $FILE);
-$VERSION = '1.11';
-$DATE = '2003/09/19';
+$VERSION = '1.12';
+$DATE = '2004/05/04';
 $FILE = __FILE__;
 
 use vars qw(@ISA @EXPORT_OK);
@@ -222,6 +222,8 @@ the L<C<ExtUtils::SVDmaker>|ExtUtils::SVDmaker> package.
 This is the focus and no other focus.
 Since C<Test::STD::Scrub> is a separate package, the methods
 may be used elsewhere.
+They are used to wild card out parts of two documents before
+they are compared by making these snippets the same.
 In all likehood, any revisions will maintain backwards compatibility
 with previous revisions.
 However, support and the performance of the 
@@ -287,303 +289,196 @@ the comparision.
 
 =head1 REQUIREMENTS
 
-Coming soon.
+Someday.
 
 =head1 DEMONSTRATION
 
- ~~~~~~ Demonstration overview ~~~~~
+ #########
+ # perl Scrub.d
+ ###
 
-Perl code begins with the prompt
+~~~~~~ Demonstration overview ~~~~~
 
- =>
+The results from executing the Perl Code 
+follow on the next lines as comments. For example,
 
-The selected results from executing the Perl Code 
-follow on the next lines. For example,
+ 2 + 2
+ # 4
 
- => 2 + 2
- 4
+~~~~~~ The demonstration follows ~~~~~
 
- ~~~~~~ The demonstration follows ~~~~~
+     use File::Spec;
 
- =>     use File::Spec;
+     use File::Package;
+     my $fp = 'File::Package';
 
- =>     use File::Package;
- =>     my $fp = 'File::Package';
+     my $uut = 'Text::Scrub';
 
- =>     my $uut = 'Text::Scrub';
+     my $loaded = '';
+     my $template = '';
+     my %variables = ();
+     my $expected = '';
 
- =>     my $loaded = '';
- =>     my $template = '';
- =>     my %variables = ();
- =>     my $expected = '';
- => my $errors = $fp->load_package($uut)
- => $errors
- ''
+ ##################
+ # Load UUT
+ # 
 
- => my $text = 'ok 2 # (E:/User/SoftwareDiamonds/installation/t/Test/STDmaker/tgA1.t at line 123 TODO?!)'
- => $uut->scrub_file_line($text)
- 'ok 2 # (xxxx.t at line 000 TODO?!)'
+ my $errors = $fp->load_package($uut)
+ $errors
 
- => $text = 'Running Tests\n\nE:/User/SoftwareDiamonds/installation/t/Test/STDmaker/tgA1.1..16 todo 2 5;'
- => $uut->scrub_test_file($text)
- 'Running Tests xxx.t 1..16 todo 2 5;'
+ # ''
+ #
 
- => $text = '$VERSION = \'0.01\';\n$DATE = \'2003/06/07\';'
- => $uut->scrub_date_version($text)
- '$VERSION = '0.00';\n$DATE = 'Feb 6, 1969';'
+ ##################
+ #  scrub_file_line
+ # 
 
- => $text = <<'EOF';
- => Date: Apr 12 00 00 00 2003 +0000
- => Subject: 20030506, This Week in Health'
- => X-SDticket: 20030205
- => X-eudora-date: Feb 6 2000 00 00 2003 +0000
- => X-SDmailit: dead Feb 5 2000 00 00 2003
- => Sent email 20030205-20030506 to support.softwarediamonds.com
- => EOF
+ my $text = 'ok 2 # (E:/User/SoftwareDiamonds/installation/t/Test/STDmaker/tgA1.t at line 123 TODO?!)'
+ $uut->scrub_file_line($text)
 
- => my $expected_text = <<'EOF';
- => Date: Feb 6 00 00 00 1969 +0000
- => Subject: XXXXXXXXX-X,  This Week in Health'
- => X-SDticket: XXXXXXXXX-X
- => X-eudora-date: Feb 6 00 00 00 1969 +0000
- => X-SDmailit: dead Sat Feb 6 00 00 00 1969 +0000
- => Sent email XXXXXXXXX-X to support.softwarediamonds.com
- => EOF
+ # 'ok 2 # (xxxx.t at line 000 TODO?!)'
+ #
 
- => # end of EOF
- => $uut->scrub_date_ticket($text)
- 'Date: Feb 6 00 00 00 1969 +0000
+ ##################
+ #  scrub_test_file
+ # 
+
+ $text = 'Running Tests\n\nE:/User/SoftwareDiamonds/installation/t/Test/STDmaker/tgA1.1..16 todo 2 5;'
+ $uut->scrub_test_file($text)
+
+ # 'Running Tests xxx.t 1..16 todo 2 5;'
+ #
+
+ ##################
+ #  scrub_date_version
+ # 
+
+ $text = '$VERSION = \'0.01\';\n$DATE = \'2003/06/07\';'
+ $uut->scrub_date_version($text)
+
+ # '$VERSION = '0.00';\n$DATE = 'Feb 6, 1969';'
+ #
+
+ ##################
+ #  scrub_date_ticket
+ # 
+
+ $text = <<'EOF';
+ Date: Apr 12 00 00 00 2003 +0000
+ Subject: 20030506, This Week in Health'
+ X-SDticket: 20030205
+ X-eudora-date: Feb 6 2000 00 00 2003 +0000
+ X-SDmailit: dead Feb 5 2000 00 00 2003
+ Sent email 20030205-20030506 to support.softwarediamonds.com
+ EOF
+
+ my $expected_text = <<'EOF';
+ Date: Feb 6 00 00 00 1969 +0000
  Subject: XXXXXXXXX-X,  This Week in Health'
  X-SDticket: XXXXXXXXX-X
  X-eudora-date: Feb 6 00 00 00 1969 +0000
  X-SDmailit: dead Sat Feb 6 00 00 00 1969 +0000
  Sent email XXXXXXXXX-X to support.softwarediamonds.com
- '
+ EOF
 
- => $text = 'Going to happy valley 2003/06/07'
- => $uut->scrub_date($text)
- 'Going to happy valley 1969/02/06'
+ # end of EOF
+ $uut->scrub_date_ticket($text)
 
- => $text = <<'EOF';
- => 1..8 todo 2 5;
- => # OS            : MSWin32
- => # Perl          : 5.6.1
- => # Local Time    : Thu Jun 19 23:49:54 2003
- => # GMT Time      : Fri Jun 20 03:49:54 2003 GMT
- => # Number Storage: string
- => # Test::Tech    : 1.06
- => # Test          : 1.15
- => # Data::Dumper  : 2.102
- => # =cut 
- => # Pass test
- => ok 1
- => EOF
+ # 'Date: Feb 6 00 00 00 1969 +0000
+ #Subject: XXXXXXXXX-X,  This Week in Health'
+ #X-SDticket: XXXXXXXXX-X
+ #X-eudora-date: Feb 6 00 00 00 1969 +0000
+ #X-SDmailit: dead Sat Feb 6 00 00 00 1969 +0000
+ #Sent email XXXXXXXXX-X to support.softwarediamonds.com
+ #'
+ #
 
- => $expected_text = <<'EOF';
- => 1..8 todo 2 5;
- => # Pass test
- => ok 1
- => EOF
+ ##################
+ #  scrub_date
+ # 
 
- => # end of EOF
- => $uut->scrub_probe($text)
- '1..8 todo 2 5;
+ $text = 'Going to happy valley 2003/06/07'
+ $uut->scrub_date($text)
+
+ # 'Going to happy valley 1969/02/06'
+ #
+
+ ##################
+ #  scrub_probe
+ # 
+
+ $text = <<'EOF';
+ 1..8 todo 2 5;
+ # OS            : MSWin32
+ # Perl          : 5.6.1
+ # Local Time    : Thu Jun 19 23:49:54 2003
+ # GMT Time      : Fri Jun 20 03:49:54 2003 GMT
+ # Number Storage: string
+ # Test::Tech    : 1.06
+ # Test          : 1.15
+ # Data::Dumper  : 2.102
+ # =cut 
  # Pass test
  ok 1
- '
+ EOF
 
- => unlink 'actual.txt'
+ $expected_text = <<'EOF';
+ 1..8 todo 2 5;
+ # Pass test
+ ok 1
+ EOF
+
+ # end of EOF
+ $uut->scrub_probe($text)
+
+ # '1..8 todo 2 5;
+ ## Pass test
+ #ok 1
+ #'
+ #
+ unlink 'actual.txt'
 
 =head1 QUALITY ASSURANCE
 
-Running the test script 'Scrub.t' found in
-the "Text-Scrub-$VERSION.tar.gz" distribution file verifies
+Running the test script C<Scrub.t> verifies
 the requirements for this module.
-
-All testing software and documentation
-stems from the 
-Software Test Description (L<STD|Docs::US_DOD::STD>)
-program module 't::Text::Scrub',
-found in the distribution file 
-"Text-Scrub-$VERSION.tar.gz". 
-
-The 't::Text::Scrub' L<STD|Docs::US_DOD::STD> POD contains
-a tracebility matix between the
-requirements established above for this module, and
-the test steps identified by a
-'ok' number from running the 'Scrub.t'
-test script.
-
-The t::Text::Scrub' L<STD|Docs::US_DOD::STD>
-program module '__DATA__' section contains the data 
-to perform the following:
-
-=over 4
-
-=item *
-
-to generate the test script 'Scrub.t'
-
-=item *
-
-generate the tailored 
-L<STD|Docs::US_DOD::STD> POD in
-the 't::Text::Scrub' module, 
-
-=item *
-
-generate the 'Scrub.d' demo script, 
-
-=item *
-
-Replace the POD demonstration section
-herein with the demo script
-'Scrub.d' output, and
-
-=item *
-
-run the test script using Test::Harness
-with or without the verbose option,
-
-=back
-
-To perform all the above, prepare
-and run the automation software as 
-follows:
-
-=over 4
-
-=item *
-
-Install "Test_STDmaker-$VERSION.tar.gz"
-from one of the respositories only
-if it has not been installed:
-
-=over 4
-
-=item *
-
-http://www.softwarediamonds/packages/
-
-=item *
-
-http://www.perl.com/CPAN-local/authors/id/S/SO/SOFTDIA/
-
-=back
-  
-=item *
-
-manually place the script tmake.pl
-in "Test_STDmaker-$VERSION.tar.gz' in
-the site operating system executable 
-path only if it is not in the 
-executable path
-
-=item *
-
-place the 't::Text::Scrub' at the same
-level in the directory struture as the
-directory holding the 'Text::Scrub'
-module
-
-=item *
-
-execute the following in any directory:
-
- tmake -test_verbose -replace -run -pm=t::Text::Scrub
-
-=back
+The C<tmake.pl> cover script for L<Test::STDmaker|Test::STDmaker>
+automatically generated the
+C<Scrub.t> test script, C<Scrub.d> demo script,
+and C<t::Text::Scrub> program module POD,
+from the C<t::Text::Scrub> program module contents.
+The C<tmake.pl> cover script automatically ran the
+C<Scrub.d> demo script and inserted the results
+into the 'DEMONSTRATION' section above.
+The  C<t::Text::Scrub> program module
+is in the distribution file
+F<Text-Scrub-$VERSION.tar.gz>.
 
 =head1 NOTES
 
-=head2 FILES
-
-The installation of the
-"Text-Scrub-$VERSION.tar.gz" distribution file
-installs the 'Docs::Site_SVD::Text_Scrub'
-L<SVD|Docs::US_DOD::SVD> program module.
-
-The __DATA__ data section of the 
-'Docs::Site_SVD::Text_Scrub' contains all
-the necessary data to generate the POD
-section of 'Docs::Site_SVD::Text_Scrub' and
-the "Text-Scrub-$VERSION.tar.gz" distribution file.
-
-To make use of the 
-'Docs::Site_SVD::Text_Scrub'
-L<SVD|Docs::US_DOD::SVD> program module,
-perform the following:
-
-=over 4
-
-=item *
-
-install "ExtUtils-SVDmaker-$VERSION.tar.gz"
-from one of the respositories only
-if it has not been installed:
-
-=over 4
-
-=item *
-
-http://www.softwarediamonds/packages/
-
-=item *
-
-http://www.perl.com/CPAN-local/authors/id/S/SO/SOFTDIA/
-
-=back
-
-=item *
-
-manually place the script vmake.pl
-in "ExtUtils-SVDmaker-$VERSION.tar.gz' in
-the site operating system executable 
-path only if it is not in the 
-executable path
-
-=item *
-
-Make any appropriate changes to the
-__DATA__ section of the 'Docs::Site_SVD::Text_Scrub'
-module.
-For example, any changes to
-'Text::Scrub' will impact the
-at least 'Changes' field.
-
-=item *
-
-Execute the following:
-
- vmake readme_html all -pm=Docs::Site_SVD::Text_Scrub
-
-=back
-
-=head1 NOTES
-
-=head2 AUTHOR
+=head2 Author
 
 The holder of the copyright and maintainer is
 
 E<lt>support@SoftwareDiamonds.comE<gt>
 
-=head2 COPYRIGHT NOTICE
+=head2 Copyright
 
 Copyrighted (c) 2002 Software Diamonds
 
 All Rights Reserved
 
-=head2 BINDING REQUIREMENTS NOTICE
+=head2 Binding Requirements
 
 Binding requirements are indexed with the
 pharse 'shall[dd]' where dd is an unique number
 for each header section.
 This conforms to standard federal
-government practices, 490A (L<STD490A/3.2.3.6>).
+government practices, L<STD490A 3.2.3.6|Docs::US_DOD::STD490A/3.2.3.6>.
 In accordance with the License, Software Diamonds
 is not liable for any requirement, binding or otherwise.
 
-=head2 LICENSE
+=head2 License
 
 Software Diamonds permits the redistribution
 and use in source and binary forms, with or
@@ -609,7 +504,7 @@ distribution.
 
 =back
 
-SOFTWARE DIAMONDS, http::www.softwarediamonds.com,
+SOFTWARE DIAMONDS, http://www.softwarediamonds.com,
 PROVIDES THIS SOFTWARE 
 'AS IS' AND ANY EXPRESS OR IMPLIED WARRANTIES,
 INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
@@ -626,23 +521,19 @@ OR TORT (INCLUDING USE OF THIS SOFTWARE, EVEN IF
 ADVISED OF NEGLIGENCE OR OTHERWISE) ARISING IN
 ANY WAY OUT OF THE POSSIBILITY OF SUCH DAMAGE. 
 
-=for html
-<p><br>
-<!-- BLK ID="NOTICE" -->
-<!-- /BLK -->
-<p><br>
-<!-- BLK ID="OPT-IN" -->
-<!-- /BLK -->
-<p><br>
-<!-- BLK ID="EMAIL" -->
-<!-- /BLK -->
-<p><br>
-<!-- BLK ID="COPYRIGHT" -->
-<!-- /BLK -->
-<p><br>
-<!-- BLK ID="LOG_CGI" -->
-<!-- /BLK -->
-<p><br>
+=head1 SEE ALSO
+
+=over 4
+
+=item L<Docs::Site_SVD::Text_Srube|Docs::Site_SVD::Text_Scrub>
+
+=item L<Test::STDmaker|Test::STDmaker>
+
+=item L<ExtUtils::SVDmaker|ExtUtils::SVDmaker> 
+
+=item L
+
+=back
 
 =cut
 
